# Copyright (c) Facebook, Inc. and its affiliates. All Rights Reserved.

from iopath.common.file_io import (
    LazyPath,
    PathManager,
    get_cache_dir,
    file_lock,
)

__all__ = [
    "LazyPath",
    "PathManager",
    "get_cache_dir",
    "file_lock",
]



# Copyright (c) Facebook, Inc. and its affiliates. All Rights Reserved.

from iopath.common import (
    LazyPath,
    PathManager,
    get_cache_dir,
    file_lock,
)

from iopath.tabular.tabular_io import (
    TabularPathHandler,
    TabularUriParser,
)

__all__ = [
    "LazyPath",
    "PathManager",
    "get_cache_dir",
    "file_lock",
    "TabularPathHandler",
    "TabularUriParser",
]

# This line will be programatically read/write by setup.py.
# Leave them at the bottom of this file and don't touch them.
__version__ = "0.1.6"



# Copyright (c) Facebook, Inc. and its affiliates. All Rights Reserved.

from typing import Any, Iterable

from iopath.common.file_io import PathHandler

class TabularUriParser:
    def parse_uri(self, uri: str) ->None:
        pass

class TabularPathHandler(PathHandler):
    def _opent(
        self, path: str, mode: str = "r", buffering: int = 32, **kwargs: Any
    ) -> Iterable[Any]:
        assert mode == "r"
